GoogleMapsAction class abstract

Inheritance
  • Object
  • WarnableClass
  • ActionEntity
  • GoogleMapsAction
Implementers

Constructors

GoogleMapsAction({required String id, String type = '', String group = GMActionGroups.googleMaps, required ID controllerID})
const

Properties

controllerID → ID
final
group → ID
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id → ID
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → ID
finalinherited

Methods

getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() → ID
A string representation of this object.
inherited
toStringGroup() → ID
override
toStringName() → ID
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) GoogleMapsAction
override