GoogleMapsChangePositionAction class

Inheritance

Constructors

GoogleMapsChangePositionAction({required String id, String type = 'google_maps_change_position', required ID controllerID, required ConditionParameter lat, required ConditionParameter lng})
const

Properties

controllerID → ID
finalinherited
group → ID
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id → ID
finalinherited
lat → ConditionParameter
final
lng → ConditionParameter
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → ID
finalinherited

Methods

copyWith({ID? id, String? type, ActionGroups? group, ID? controllerID, ConditionParameter? lat, ConditionParameter? lng}) GoogleMapsChangePositionAction
getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() → ID
A string representation of this object.
inherited
toStringGroup() → ID
inherited
toStringName() → ID
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) GoogleMapsAction
override